| Title: | Get data about french traffic prevision |
|---|---|
| Description: | Functions to easily get data from Bison Fute (www.bison-fute.gouv.fr), french public service about traffic prevision. |
| Authors: | Christophe Dervieux [aut, cre] |
| Maintainer: | Christophe Dervieux <[email protected]> |
| License: | MIT + file LICENSE |
| Version: | 0.0.0.9000 |
| Built: | 2026-06-10 16:04:32 UTC |
| Source: | https://github.com/cderv/bfr |
bison fute website uses data from past date and future date for its previsions color of departement. See http://www.bison-fute.gouv.fr/previsions,10564.html
get_all_previsions_available()get_all_previsions_available()
a tibble